pymergedocx package
===================

Submodules
----------

pymergedocx.cli module
----------------------

.. automodule:: pymergedocx.cli
    :members:
    :undoc-members:
    :show-inheritance:

pymergedocx.pymergedocx module
------------------------------

.. automodule:: pymergedocx.pymergedocx
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pymergedocx
    :members:
    :undoc-members:
    :show-inheritance:
